<?php
/*
Plugin Name: PixoPoint Google Calendar
Plugin URI: http://pixopoint.com/
Description: Allows users to add embed code from Google Calendar
Author: PixoPoint
Version: 0.1.2
Author URI: http://pixopoint.com/
*/


/**
 * Content parser
 * Converts JS into WordPress shortcode
 * @since 0.1
 */
function pixopoint_google_calendar_filter( $content ) {
	// header("Content-Type: plain/text"); - useful for debugging purposes

	// WordPress converts " into \" so needed to convert them back to make sure it's all kosher for the regex :)
	$content = str_replace( '\"', '"', $content );

	// Google Calendar
	$content = preg_replace(
		'/<iframe src="(http:\/\/www.google.com\/calendar\/.*?)".*<\/iframe>/',
		'[googlecalender $1]',
		$content
	);

	return $content;
}
add_filter( 'content_save_pre', 'pixopoint_google_calendar_filter' );

/**
 * Google Calendar [googlecalender] shortcode
 * @since 0.1
 */
function pixopoint_google_calendar_shortcode( $data ) {

	// Getting size data
	$size = $data['w'];
	str_replace( '&#038;h=', '&amp;h=', $size );
	$size = explode( '&amp;h=', $size );
	$w = $size[0];
	$h = $size[1];
	if ( !is_int( $w ) )
		$w = 600; // fallback if invalid width given
	if ( !is_int( $w ) )
		$h = 600; // fallback if invalid height given

	// Sanitizing URL
	$url = $data[0];
	$url = esc_url( $url );

	// Print reformed embed code on screen
	return '
<iframe src="' . $url . '" style="border: 0" width="' . $w . '" height="' . $h . '" frameborder="0" scrolling="no"></iframe>
';
}
add_shortcode( 'googlecalender', 'pixopoint_google_calendar_shortcode' );

/**
 * Converts various Google TLDs to google.com
 * @since 0.1
 */
if ( !function_exists( 'pixopoint_google_tld_rewriter' ) ) :
function pixopoint_google_tld_rewriter( $data ) {
	$tlds = array(
		'google.de',
		'google.com',
		'google.at',
		'google.pl',
		'google.fr',
		'google.nl',
		'google.it',
		'google.com.tr',
		'google.es',
		'google.ch',
		'google.be',
		'google.gr',
		'google.com.br',
		'google.lu',
		'google.fi',
		'google.pt',
		'google.hu',
		'google.hr',
		'google.bg',
		'google.com.mx',
		'google.si',
		'google.sk',
		'google.ro',
		'google.ca',
		'google.co.uk',
		'google.cl',
		'google.com.ar',
		'google.se',
		'google.cz',
		'google.dk',
		'google.co.th',
		'google.com.co',
		'google.lt',
		'google.co.id',
		'google.co.in',
		'google.co.il',
		'google.com.eg',
		'google.cn',
		'google.co.ve',
		'google.ru',
		'google.co.jp',
		'google.com.pe',
		'google.com.au',
		'google.co.ma',
		'google.co.za',
		'google.com.ph',
		'google.com.sa',
		'google.ie',
		'google.co.kr',
		'google.no',
		'google.com.ec',
		'google.com.vn',
		'google.lv',
		'google.com.mt',
		'google.com.uy',
		'google.ae',
		'google.ba',
		'google.co.nz',
		'google.com.ua',
		'google.co.cr',
		'google.ee',
		'google.com.do',
		'google.com.tw',
		'google.com.hk',
		'google.com.my',
		'google.com.sv',
		'google.com.pr',
		'google.lk',
		'google.com.gt',
		'google.com.bd',
		'google.com.pk',
		'google.is',
		'google.li',
		'google.com.bh',
		'google.com.ni',
		'google.com.py',
		'google.com.ng',
		'google.com.bo',
		'google.co.ke',
		'google.hn',
		'google.com.sg',
		'google.mu',
		'google.ci',
		'google.jo',
		'google.nu',
		'google.com.jm',
		'google.com.ly',
		'google.co.yu',
		'google.tt',
		'google.com.kh',
		'google.ge',
		'google.com.na',
		'google.com.et',
		'google.sm',
		'google.cd',
		'google.gm',
		'google.com.qa',
		'google.dj',
		'google.com.cu',
		'google.com.pa',
		'google.gp',
		'google.az',
		'google.as',
		'google.pl',
		'google.mn',
		'google.ht',
		'google.md',
		'google.am',
		'google.sn',
		'google.je',
		'googlee.com',
		'google.com.bn',
		'google.com.ai',
		'google.co.zm',
		'google.ma',
		'google.rw',
		'google.co.ug',
		'google.com.vc',
		'googlenews.de',
		'google.com',
		'google.at',
		'google.com.gi',
		'google.to',
		'google.com.om',
		'google.kz',
		'google.co.uz',
	);
	foreach ( $tlds as $tld ) {
		$data = str_replace( $tld, 'google.com', $data );
	}
	return $data;
}
endif;

